deeplake.util.remove_cache
==========================
.. currentmodule:: deeplake.util.remove_cache
.. autofunction:: remove_memory_cache
.. autofunction:: get_base_storage
.. autofunction:: get_dataset_with_zero_size_cache
.. autofunction:: create_read_copy_dataset